@@ -380,6 +380,15 @@ if [ -z "$signcommand" ]; then
     exit 1
 fi
 
+if echo "${signkey}" | grep -E -qs '^(0x)?[a-zA-Z0-9]{8}$'; then
+    echo "Refusing to sign with short key ID '$signkey'!" >&2
+    exit 1
+fi
+
+if echo "${signkey}" | grep -E -qs '^(0x)?[a-zA-Z0-9]{16}$'; then
+    echo "long key IDs are discouraged; please use key fingerprints instead" >&2
+fi
+
 ensure_local_copy() {
     local remotehost="$1"
     local remotefile="$2"
@@ -415,8 +424,8 @@ fixup_control() {
     local sha1=$(sha1sum "$child" | cut -d' ' -f1)
     local sha256=$(sha256sum "$child" | cut -d' ' -f1)
     perl -i -pe 'BEGIN {
-    '" \$file=\"$child\"; \$md5=\"$md5\"; "'
-    '" \$sha1=\"$sha1\"; \$sha256=\"$sha256\"; "'
+    '" \$file='$child'; \$md5='$md5'; "'
+    '" \$sha1='$sha1'; \$sha256='$sha256'; "'
     $size=(-s $file); ($base=$file) =~ s|.*/||;
     $infiles=0; $inmd5=0; $insha1=0; $insha256=0; $format="";
     }
@@ -725,7 +734,7 @@ for valid format" >&2;
 	report_signed
 
     else
-	ensure_local_copy "$remotehost" "$remotehost" "$remotedsc" dsc
+	ensure_local_copy "$remotehost" "$remotedsc" "$dsc" dsc
 	signas="$(guess_signas "$dsc")"
 	maybesign_dsc "$signas" "$remotehost" "$dsc"
 	report_signed
